@@ -23,8 +23,4 @@ out='./eval_GLEAM'
 echo
 echo VALIDATING WITH GLEAM
 
-pcru_eval_poly -o E -s total_evaporation -cf 1000 -id watprovID --plot $shp $sim $obs $out
-
-obs='../../examples/example_data/GLEAM/GLEAM_data_2010_Tanzania_annualMean.nc'
-sim='../../examples/example_data/GLEAM/totalEvaporation_monthTot_output_2010_Tanzania_annualMean.nc'
-out='./eval_GLEAM_annualMean'
\ No newline at end of file
+pcru_eval_poly -o E -s total_evaporation -cf 1000 -id watprovID --plot $shp $sim $obs $out
\ No newline at end of file
